@@ -39,11 +39,6 @@ class CatBoostManager(ModelManager):
     https://catboost.ai/docs/concepts/apply-onnx-ml.html
     """
 
-    @classmethod
-    def name(cls) -> str:
-        """ Returns the name of this model type """
-        return "catboost"
-
     @classmethod
     def required_dependencies(cls) -> list:
         return ["catboost", "onnxruntime"]
@@ -51,9 +46,13 @@ class CatBoostManager(ModelManager):
     def _required_kwargs(self):
         return ["model"]
 
-    def model_info(self, **kwargs) -> dict:
+    def _model_info(self, **kwargs) -> dict:
         """ Returns meta-data about the model's type """
-        return {"type": type(kwargs["model"]).__name__}
+        return {"library": "catboost", "type": type(kwargs["model"]).__name__}
+
+    def _model_data(self, **kwargs) -> dict:
+        """ Returns meta-data about the data used to train the model """
+        return {}
 
     def _get_functions(self, **kwargs) -> list:
         import catboost
@@ -68,11 +67,19 @@ class CatBoostManager(ModelManager):
             partial(dump_attributes, model=kwargs["model"]),
         ]
 
+    def _get_params(self, **kwargs) -> dict:
+        """
+        Returns a dictionary containing any model parameters
+        that are available
+        https://catboost.ai/docs/concepts/python-reference_catboost_get_params.html
+        """
+        return kwargs["model"].get_params()
+
 
 def save_model(
     tmp_dir: str, model: "catboost.CatBoost", fmt: str, pool: Any = None
 ) -> str:
-    """ CatBoost supports storing models in multiple formats:
+    """CatBoost supports storing models in multiple formats:
     https://catboost.ai/docs/concepts/python-reference_catboost_save_model.html#python-reference_catboost_save_model
     """
     logger.debug("Saving catboost model as %s", fmt)
