@@ -30,11 +30,6 @@ class KerasManager(ModelManager):
     https://keras.io/guides/serialization_and_saving/
     """
 
-    @classmethod
-    def name(cls) -> str:
-        """ Returns the name of this model type """
-        return "keras"
-
     @classmethod
     def required_dependencies(cls) -> list:
         return [
@@ -48,17 +43,32 @@ class KerasManager(ModelManager):
     def _required_kwargs(self):
         return ["model"]
 
-    def model_info(self, **kwargs) -> dict:
+    def _model_info(self, **kwargs) -> dict:
         """ Returns meta-data about the model's type """
+        return {"library": "keras"}
+
+    def _model_data(self, **kwargs) -> dict:
+        """ Returns meta-data about the data used to train the model """
         return {}
 
     def _get_functions(self, **kwargs) -> list:
         model = kwargs["model"]
         return [
             partial(_save_model, model=model),
-            partial(save_json, file_name=MODEL_CONFIG, data=model.to_json(),),
+            partial(
+                save_json,
+                file_name=MODEL_CONFIG,
+                data=model.to_json(),
+            ),
         ]
 
+    def _get_params(self, **kwargs) -> dict:
+        """
+        Returns a dictionary containing the optimizer
+        parameters
+        """
+        return kwargs["model"].optimizer.get_config()
+
 
 def _save_model(tmp_dir: str, model: "keras.Model") -> str:
     import keras
