@@ -13,27 +13,33 @@
 #    limitations under the License.
 from typing import Iterator
 
-from modelstore.clouds.storage import CloudStorage
 from modelstore.meta.dependencies import module_exists
 from modelstore.models.catboost import CatBoostManager
+from modelstore.models.fastai import FastAIManager
 from modelstore.models.keras import KerasManager
+from modelstore.models.lightgbm import LightGbmManager
 from modelstore.models.missingmanager import MissingDepManager
 from modelstore.models.modelmanager import ModelManager
 from modelstore.models.pytorch import PyTorchManager
+from modelstore.models.pytorch_lightning import PyTorchLightningManager
 from modelstore.models.sklearn import SKLearnManager
 from modelstore.models.tensorflow import TensorflowManager
 from modelstore.models.transformers import TransformersManager
 from modelstore.models.xgboost import XGBoostManager
+from modelstore.storage.storage import CloudStorage
+from modelstore.utils.log import logger
 
 ML_LIBRARIES = {
-    CatBoostManager.name(): CatBoostManager,
-    KerasManager.name(): KerasManager,
-    "pytorch": PyTorchManager,  # Adding twice as this is a common typo
-    SKLearnManager.name(): SKLearnManager,
-    PyTorchManager.name(): PyTorchManager,
-    TensorflowManager.name(): TensorflowManager,
-    TransformersManager.name(): TransformersManager,
-    XGBoostManager.name(): XGBoostManager,
+    "catboost": CatBoostManager,
+    "fastai": FastAIManager,
+    "keras": KerasManager,
+    "lightgbm": LightGbmManager,
+    "pytorch": PyTorchManager,
+    "pytorch_lightning": PyTorchLightningManager,
+    "sklearn": SKLearnManager,
+    "tensorflow": TensorflowManager,
+    "transformers": TransformersManager,
+    "xgboost": XGBoostManager,
 }
 
 
@@ -42,4 +48,5 @@ def iter_libraries(storage: CloudStorage = None) -> Iterator[ModelManager]:
         if all(module_exists(x) for x in mngr.required_dependencies()):
             yield library, mngr(storage)
         else:
+            logger.debug("Skipping: %s, not installed.", library)
             yield library, MissingDepManager(library, storage)
