@@ -11,23 +11,21 @@
 #    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
-from modelstore.clouds.storage import CloudStorage
 from modelstore.models.modelmanager import ModelManager
+from modelstore.storage.storage import CloudStorage
 from modelstore.utils.log import logger
 
 
 class MissingDepManager(ModelManager):
 
     """
-        MissingDepManager is used when a dependency is not
-        installed; it overrides the ModelManager functionality
-        and gives the user informative error messages
-        """
+    MissingDepManager is used when a dependency is not
+    installed; it overrides the ModelManager functionality
+    and gives the user informative error messages
+    """
 
     def __init__(self, library: str, storage: CloudStorage = None):
         super().__init__(storage)
-        if library == "pytorch":
-            library = "torch"
         self.library = library
 
     @classmethod
@@ -42,11 +40,17 @@ class MissingDepManager(ModelManager):
     def _get_functions(self, **kwargs) -> list:
         return []
 
+    def _get_params(self, **kwargs) -> dict:
+        return None
+
     def _required_kwargs(self) -> list:
         return []
 
-    def model_info(self, **kwargs) -> dict:
-        return {}
+    def _model_info(self, **kwargs) -> dict:
+        return None
+
+    def _model_data(self, **kwargs) -> dict:
+        return None
 
     def upload(self, domain: str, **kwargs) -> str:
         logger.error("Error: %s is not installed", self.library)
