@@ -16,6 +16,7 @@ import os
 from functools import partial
 
 from modelstore.models.modelmanager import ModelManager
+from modelstore.models.util import convert_numpy, convert_tensors
 
 # pylint disable=import-outside-toplevel
 MODEL_CHECKPOINT = "checkpoint.pt"
@@ -31,27 +32,26 @@ class PyTorchManager(ModelManager):
     https://pytorch.org/tutorials/recipes/recipes/saving_and_loading_models_for_inference.html
     """
 
-    @classmethod
-    def name(cls) -> str:
-        """ Returns the name of this model type """
-        return "torch"
-
     @classmethod
     def required_dependencies(cls) -> list:
         return ["torch"]
 
     @classmethod
     def optional_dependencies(cls) -> list:
-        """ Returns a list of dependencies that, if installed
-        are useful to log info about """
+        """Returns a list of dependencies that, if installed
+        are useful to log info about"""
         deps = super().optional_dependencies()
         return deps + ["torchvision"]
 
     def _required_kwargs(self):
         return ["model", "optimizer"]
 
-    def model_info(self, **kwargs) -> dict:
+    def _model_info(self, **kwargs) -> dict:
         """ Returns meta-data about the model's type """
+        return {"library": "pytorch"}
+
+    def _model_data(self, **kwargs) -> dict:
+        """ Returns meta-data about the data used to train the model """
         return {}
 
     def _get_functions(self, **kwargs) -> list:
@@ -64,6 +64,15 @@ class PyTorchManager(ModelManager):
             partial(_save_model, model=kwargs["model"]),
         ]
 
+    def _get_params(self, **kwargs) -> dict:
+        """
+        Returns a dictionary the optimizer's state
+        dictionary
+        """
+        params = kwargs["optimizer"].state_dict()
+        params = convert_numpy(params)
+        return convert_tensors(params)
+
 
 def _save_state_dict(
     tmp_dir: str, model: "nn.Module", optimizer: "optim.Optimizer"
