@@ -31,28 +31,27 @@ class XGBoostManager(ModelManager):
     https://xgboost.readthedocs.io/en/latest/tutorials/saving_model.html
     """
 
-    @classmethod
-    def name(cls) -> str:
-        """ Returns the name of this model type """
-        return "xgboost"
-
     @classmethod
     def required_dependencies(cls) -> list:
         return ["xgboost"]
 
     @classmethod
     def optional_dependencies(cls) -> list:
-        """ Returns a list of dependencies that, if installed
-        are useful to log info about """
+        """Returns a list of dependencies that, if installed
+        are useful to log info about"""
         deps = super().optional_dependencies()
         return deps + ["sklearn"]
 
     def _required_kwargs(self):
         return ["model"]
 
-    def model_info(self, **kwargs) -> dict:
+    def _model_info(self, **kwargs) -> dict:
         """ Returns meta-data about the model's type """
-        return {"type": type(kwargs["model"]).__name__}
+        return {"library": "xgboost", "type": type(kwargs["model"]).__name__}
+
+    def _model_data(self, **kwargs) -> dict:
+        """ Returns meta-data about the data used to train the model """
+        return {}
 
     def _get_functions(self, **kwargs) -> list:
         return [
@@ -61,9 +60,16 @@ class XGBoostManager(ModelManager):
             partial(model_config, model=kwargs["model"]),
         ]
 
+    def _get_params(self, **kwargs) -> dict:
+        """
+        Returns a dictionary containing any model parameters
+        that are available
+        """
+        return kwargs["model"].get_xgb_params()
+
 
 def save_model(tmp_dir: str, model: "xgb.XGBModel") -> str:
-    """  From the docs:
+    """From the docs:
     The model is saved in an XGBoost internal format which is universal
     among the various XGBoost interfaces.
     """
@@ -74,7 +80,7 @@ def save_model(tmp_dir: str, model: "xgb.XGBModel") -> str:
 
 
 def dump_model(tmp_dir: str, model: "xgb.XGBModel") -> str:
-    """ From the docs:
+    """From the docs:
     Dump model into a text or JSON file.  Unlike `save_model`, the
     output format is primarily used for visualization or interpretation
     """
