@@ -16,22 +16,21 @@ import json
 import os
 
 import catboost as ctb
-import numpy as np
 import pytest
 from modelstore.models import catboost
+from tests.models.utils import classification_data
 
 # pylint: disable=protected-access
 # pylint: disable=redefined-outer-name
 
 
 @pytest.fixture
-def catb_model():
-    model = ctb.CatBoostClassifier(loss_function="MultiClass")
-    x = np.random.rand(10, 10)
-    y = np.random.randint(0, 2, size=(10))
-    while len(np.unique(y)) == 1:
-        y = np.random.randint(0, 2, size=(10))
-    model.fit(x, y)
+def catb_model(tmpdir, classification_data):
+    model = ctb.CatBoostClassifier(
+        loss_function="MultiClass", train_dir=str(tmpdir)
+    )
+    X_train, y_train = classification_data
+    model.fit(X_train, y_train)
     return model
 
 
@@ -40,13 +39,15 @@ def catboost_manager():
     return catboost.CatBoostManager()
 
 
-def test_name(catboost_manager):
-    assert catboost_manager.name() == "catboost"
-
-
 def test_model_info(catboost_manager, catb_model):
-    exp = {"type": "CatBoostClassifier"}
-    res = catboost_manager.model_info(model=catb_model)
+    exp = {"library": "catboost", "type": "CatBoostClassifier"}
+    res = catboost_manager._model_info(model=catb_model)
+    assert exp == res
+
+
+def test_model_data(catboost_manager, catb_model):
+    exp = {}
+    res = catboost_manager._model_data(model=catb_model)
     assert exp == res
 
 
@@ -54,10 +55,16 @@ def test_required_kwargs(catboost_manager):
     assert catboost_manager._required_kwargs() == ["model"]
 
 
-def test_get_functions(catb_model, catboost_manager):
+def test_get_functions(catboost_manager, catb_model):
     assert len(catboost_manager._get_functions(model=catb_model)) == 4
 
 
+def test_get_params(catboost_manager, catb_model):
+    exp = catb_model.get_params()
+    res = catboost_manager._get_params(model=catb_model)
+    assert exp == res
+
+
 @pytest.mark.parametrize("fmt", ["json", "cbm", "onnx"])
 def test_save_model(fmt, catb_model, tmp_path):
     exp = os.path.join(tmp_path, f"model.{fmt}")
