@@ -18,7 +18,6 @@ import os
 import keras
 import numpy as np
 import pytest
-
 from modelstore.models.keras import KerasManager, _save_model, save_json
 
 # pylint: disable=protected-access
@@ -39,13 +38,15 @@ def keras_manager():
     return KerasManager()
 
 
-def test_name(keras_manager):
-    assert keras_manager.name() == "keras"
-
-
 def test_model_info(keras_manager):
+    exp = {"library": "keras"}
+    res = keras_manager._model_info()
+    assert exp == res
+
+
+def test_model_data(keras_manager, keras_model):
     exp = {}
-    res = keras_manager.model_info()
+    res = keras_manager._model_data(model=keras_model)
     assert exp == res
 
 
@@ -57,6 +58,12 @@ def test_get_functions(keras_manager, keras_model):
     assert len(keras_manager._get_functions(model=keras_model)) == 2
 
 
+def test_get_params(keras_manager, keras_model):
+    exp = keras_model.optimizer.get_config()
+    res = keras_manager._get_params(model=keras_model)
+    assert exp == res
+
+
 def test_save_model(keras_model, tmp_path):
     exp = os.path.join(tmp_path, "model")
     model_path = _save_model(tmp_path, keras_model)
