@@ -15,6 +15,7 @@
 from modelstore.models import managers
 from modelstore.models.catboost import CatBoostManager
 from modelstore.models.pytorch import PyTorchManager
+from modelstore.models.pytorch_lightning import PyTorchLightningManager
 from modelstore.models.sklearn import SKLearnManager
 from modelstore.models.xgboost import XGBoostManager
 
@@ -23,6 +24,6 @@ def test_iter_libraries():
     mgrs = {library: manager for library, manager in managers.iter_libraries()}
     assert isinstance(mgrs["sklearn"], SKLearnManager)
     assert isinstance(mgrs["pytorch"], PyTorchManager)
-    assert isinstance(mgrs["torch"], PyTorchManager)
     assert isinstance(mgrs["xgboost"], XGBoostManager)
     assert isinstance(mgrs["catboost"], CatBoostManager)
+    assert isinstance(mgrs["pytorch_lightning"], PyTorchLightningManager)
