@@ -11,22 +11,21 @@
 #    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
-
 import os
 
 import pytest
 import torch
-from torch import nn, optim
-from torch.nn import functional as F
-
 from modelstore.models.pytorch import (
     PyTorchManager,
     _save_model,
     _save_state_dict,
 )
+from torch import nn, optim
+from torch.nn import functional as F
 
 # pylint: disable=protected-access
 # pylint: disable=redefined-outer-name
+# pylint: disable=missing-class-docstring
 
 
 class ExampleNet(nn.Module):
@@ -64,13 +63,15 @@ def torch_manager():
     return PyTorchManager()
 
 
-def test_name(torch_manager):
-    assert torch_manager.name() == "torch"
-
-
 def test_model_info(torch_manager, pytorch_model):
+    exp = {"library": "pytorch"}
+    res = torch_manager._model_info(model=pytorch_model)
+    assert exp == res
+
+
+def test_model_data(torch_manager, pytorch_model):
     exp = {}
-    res = torch_manager.model_info(model=pytorch_model)
+    res = torch_manager._model_data(model=pytorch_model)
     assert exp == res
 
 
@@ -84,6 +85,14 @@ def test_get_functions(torch_manager):
     )
 
 
+def test_get_params(torch_manager, pytorch_model, pytorch_optim):
+    exp = pytorch_optim.state_dict()
+    res = torch_manager._get_params(
+        model=pytorch_model, optimizer=pytorch_optim
+    )
+    assert exp == res
+
+
 def models_equal(model_a: nn.Module, module_b: nn.Module):
     for a_params, lb_params in zip(model_a.parameters(), module_b.parameters()):
         assert a_params.data.ne(lb_params.data).sum() == 0
