@@ -11,25 +11,22 @@
 #    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
-
 import os
 
-import numpy as np
 import pytest
 import xgboost as xgb
-
 from modelstore.models import xgboost
+from tests.models.utils import classification_data
 
 # pylint: disable=protected-access
 # pylint: disable=redefined-outer-name
 
 
 @pytest.fixture
-def xgb_model():
-    model = xgb.XGBClassifier()
-    x = np.random.rand(5, 5)
-    y = np.random.randint(0, 2, size=(5))
-    model.fit(x, y)
+def xgb_model(classification_data):
+    X_train, y_train = classification_data
+    model = xgb.XGBClassifier(use_label_encoder=False)
+    model.fit(X_train, y_train)
     return model
 
 
@@ -38,13 +35,15 @@ def xgboost_manager():
     return xgboost.XGBoostManager()
 
 
-def test_name(xgboost_manager):
-    assert xgboost_manager.name() == "xgboost"
-
-
 def test_model_info(xgboost_manager, xgb_model):
-    exp = {"type": "XGBClassifier"}
-    res = xgboost_manager.model_info(model=xgb_model)
+    exp = {"library": "xgboost", "type": "XGBClassifier"}
+    res = xgboost_manager._model_info(model=xgb_model)
+    assert exp == res
+
+
+def test_model_data(xgboost_manager, xgb_model):
+    exp = {}
+    res = xgboost_manager._model_data(model=xgb_model)
     assert exp == res
 
 
@@ -56,6 +55,12 @@ def test_get_functions(xgboost_manager):
     assert len(xgboost_manager._get_functions(model="model")) == 3
 
 
+def test_get_params(xgboost_manager, xgb_model):
+    exp = xgb_model.get_xgb_params()
+    res = xgboost_manager._get_params(model=xgb_model)
+    assert exp == res
+
+
 def test_save_model(xgb_model, tmp_path):
     res = xgboost.save_model(tmp_path, xgb_model)
     exp = os.path.join(tmp_path, "model.xgboost")
